define({ root:

//begin v1.x content
{
	"field-thu-narrow-relative+0": "this Thursday",
	"field-thu-narrow-relative+1": "next Thursday",
	"field-sun-narrow-relative+0": "this Sunday",
	"field-day-short@localeAlias357": {
		"bundle": "",
		"target": "field-day"
	},
	"field-sun-narrow-relative+1": "next Sunday",
	"months-format-wide": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"field-month-short@localeAlias348": {
		"bundle": "",
		"target": "field-month"
	},
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "HH:mm:ss",
	"months-format-abbr@localeAlias302": {
		"bundle": "chinese",
		"target": "months-format-wide"
	},
	"field-fri-narrow-relative+0": "this Friday",
	"field-fri-narrow-relative+1": "next Friday",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"days-standAlone-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "last Wednesday",
	"days-format-narrow@localeAlias310": {
		"bundle": "gregorian",
		"target": "days-standAlone-narrow"
	},
	"field-minute-narrow-relative+0": "this minute",
	"days-format-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-dayOfYear-narrow@localeAlias361": {
		"bundle": "",
		"target": "field-dayOfYear-short"
	},
	"field-weekday-short@localeAlias363": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-dayOfYear-narrow@localeAlias362": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-mon-narrow@localeAlias373": {
		"bundle": "",
		"target": "field-mon-short"
	},
	"field-mon-narrow@localeAlias374": {
		"bundle": "",
		"target": "field-mon"
	},
	"field-month-short-relative+0": "this month",
	"field-month-short-relative+1": "next month",
	"field-thu-relative+0": "this Thursday",
	"dayPeriods-format-wide-am": "AM",
	"field-thu-relative+1": "next Thursday",
	"field-fri-relative+0": "this Friday",
	"field-fri-relative+1": "next Friday",
	"dateFormatItem-yMd": "r-MM-dd",
	"field-sun-narrow@localeAlias370": {
		"bundle": "",
		"target": "field-sun-short"
	},
	"field-sun-narrow@localeAlias371": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-quarter-relative+0": "this quarter",
	"field-thu-narrow-relative+-1": "last Thursday",
	"dayPeriods@localeAlias326": {
		"bundle": "chinese",
		"target": "dayPeriods"
	},
	"field-quarter-relative+1": "next quarter",
	"dayPeriods@localeAlias327": {
		"bundle": "gregorian",
		"target": "dayPeriods"
	},
	"field-sun-short-relative+0": "this Sunday",
	"timeFormat-short": "HH:mm",
	"field-sun-short-relative+1": "next Sunday",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-Md": "MM-dd",
	"field-week-narrow": "Week",
	"field-hour-relative+0": "this hour",
	"field-day-relative+-1": "yesterday",
	"field-mon-narrow-relative+-1": "last Monday",
	"field-minute-narrow": "Minute",
	"dateFormatItem-yyyyMMM": "r(U) MMM",
	"field-thu-short-relative+0": "this Thursday",
	"field-mon-relative+0": "this Monday",
	"field-thu-short-relative+1": "next Thursday",
	"field-mon-relative+1": "next Monday",
	"dateTimeFormats-appendItem-Era": "{1} {0}",
	"field-day-narrow-relative+0": "today",
	"field-era-short": "Era",
	"field-day-narrow-relative+1": "tomorrow",
	"field-sat-narrow-relative+0": "this Saturday",
	"timeFormat-long": "HH:mm:ss z",
	"field-sat-narrow-relative+1": "next Saturday",
	"field-week-narrow-relative+0": "this week",
	"field-week-narrow-relative+1": "next week",
	"field-hour-short-relative+0": "this hour",
	"field-wed-narrow-relative+0": "this Wednesday",
	"field-wed-narrow-relative+1": "next Wednesday",
	"field-month": "Month",
	"months-standAlone-wide": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"field-weekday-narrow@localeAlias364": {
		"bundle": "",
		"target": "field-weekday-short"
	},
	"field-weekday-narrow": "Day of the Week",
	"field-weekday-narrow@localeAlias365": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"field-week-narrow@localeAlias352": {
		"bundle": "",
		"target": "field-week-short"
	},
	"field-week-narrow@localeAlias353": {
		"bundle": "",
		"target": "field-week"
	},
	"field-era-narrow@localeAlias340": {
		"bundle": "",
		"target": "field-era-short"
	},
	"field-era-narrow@localeAlias341": {
		"bundle": "",
		"target": "field-era"
	},
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"months-format-narrow@localeAlias303": {
		"bundle": "chinese",
		"target": "months-standAlone-narrow"
	},
	"months@localeAlias301": {
		"bundle": "chinese",
		"target": "months"
	},
	"field-minute-short-relative+0": "this minute",
	"dateFormatItem-hm": "h:mm a",
	"field-year-narrow": "Year",
	"field-fri-short@localeAlias384": {
		"bundle": "",
		"target": "field-fri"
	},
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"field-hour-narrow@localeAlias394": {
		"bundle": "",
		"target": "field-hour-short"
	},
	"field-hour-narrow@localeAlias395": {
		"bundle": "",
		"target": "field-hour"
	},
	"field-tue-short-relative+0": "this Tuesday",
	"field-tue-short-relative+1": "next Tuesday",
	"dateTimeFormats-appendItem-Year": "{1} {0}",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"field-tue-narrow-relative+0": "this Tuesday",
	"field-tue-narrow-relative+1": "next Tuesday",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "HH",
	"quarters-standAlone-abbr@localeAlias323": {
		"bundle": "gregorian",
		"target": "quarters-format-abbr"
	},
	"quarters-standAlone-abbr@localeAlias324": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-wed-relative+0": "this Wednesday",
	"field-thu-narrow@localeAlias382": {
		"bundle": "",
		"target": "field-thu-short"
	},
	"field-weekOfMonth-narrow@localeAlias355": {
		"bundle": "",
		"target": "field-weekOfMonth-short"
	},
	"field-wed-relative+1": "next Wednesday",
	"field-thu-narrow@localeAlias383": {
		"bundle": "",
		"target": "field-thu"
	},
	"dateFormatItem-M": "L",
	"field-weekOfMonth-narrow@localeAlias356": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"field-wed-short-relative+0": "this Wednesday",
	"days@localeAlias307": {
		"bundle": "chinese",
		"target": "days"
	},
	"field-wed-short-relative+1": "next Wednesday",
	"field-fri-short-relative+0": "this Friday",
	"days@localeAlias308": {
		"bundle": "gregorian",
		"target": "days"
	},
	"field-weekOfMonth-short": "Week Of Month",
	"field-fri-short-relative+1": "next Friday",
	"field-quarter-short-relative+-1": "last quarter",
	"field-dayperiod-narrow@localeAlias391": {
		"bundle": "",
		"target": "field-dayperiod-short"
	},
	"field-year-short-relative+-1": "last year",
	"field-dayperiod-narrow@localeAlias392": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"dateFormatItem-Bhm": "h:mm B",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dayPeriods-standAlone-wide@localeAlias333": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-wide@localeAlias334": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"dateTimeFormat-medium": "{1} {0}",
	"field-quarter-narrow-relative+-1": "last quarter",
	"dateFormatItem-d": "d",
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-h": "h a",
	"quarters-standAlone-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-weekOfMonth-narrow": "Week Of Month",
	"field-dayperiod-short@localeAlias390": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"dateFormatItem-yyyyQQQ": "r(U) QQQ",
	"dateFormatItem-yyyyMMMM": "r(U) MMMM",
	"dateFormatItem-y": "r(U)",
	"field-minute-relative+0": "this minute",
	"field-year-short-relative+0": "this year",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-week-short@localeAlias351": {
		"bundle": "",
		"target": "field-week"
	},
	"field-year-short-relative+1": "next year",
	"field-weekday": "Day of the Week",
	"dayPeriods-format-narrow-pm": "PM",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-tue-narrow-relative+-1": "last Tuesday",
	"field-fri-narrow@localeAlias385": {
		"bundle": "",
		"target": "field-fri-short"
	},
	"field-fri-narrow@localeAlias386": {
		"bundle": "",
		"target": "field-fri"
	},
	"field-year-narrow-relative+-1": "last year",
	"dateFormatItem-yyyyMMMd": "r MMM d",
	"field-sat-relative+-1": "last Saturday",
	"quarters-format-abbr@localeAlias321": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"dateFormatItem-UMMM": "U MMM",
	"dayPeriods-standAlone-narrow-pm": "PM",
	"field-mon-narrow-relative+0": "this Monday",
	"field-mon-narrow-relative+1": "next Monday",
	"field-second": "Second",
	"field-year-relative+-1": "last year",
	"field-weekdayOfMonth-short": "Weekday Of Month",
	"dateFormat-short": "r-MM-dd",
	"field-second-short": "Second",
	"field-thu-short-relative+-1": "last Thursday",
	"field-zone": "Zone",
	"field-dayperiod-narrow": "Dayperiod",
	"field-sun-short-relative+-1": "last Sunday",
	"dateFormatItem-UM": "U MM",
	"dateFormat@localeAlias335": {
		"bundle": "chinese",
		"target": "dateFormat"
	},
	"field-week-short": "Week",
	"dayPeriods-standAlone-abbr-am": "AM",
	"field-minute-narrow@localeAlias397": {
		"bundle": "",
		"target": "field-minute-short"
	},
	"field-minute-narrow@localeAlias398": {
		"bundle": "",
		"target": "field-minute"
	},
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-ms": "mm:ss",
	"field-sun-short@localeAlias369": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-quarter-short@localeAlias345": {
		"bundle": "",
		"target": "field-quarter"
	},
	"field-day-short-relative+0": "today",
	"field-dayOfYear-short": "Day Of Year",
	"field-day-short-relative+1": "tomorrow",
	"dateFormat-long": "r(U) MMMM d",
	"field-sun-narrow-relative+-1": "last Sunday",
	"dayPeriods-format-wide@localeAlias329": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-second-relative+0": "now",
	"field-quarter-relative+-1": "last quarter",
	"field-quarter-narrow@localeAlias346": {
		"bundle": "",
		"target": "field-quarter-short"
	},
	"field-quarter-narrow@localeAlias347": {
		"bundle": "",
		"target": "field-quarter"
	},
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-dayOfYear-short@localeAlias360": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-week-relative+-1": "last week",
	"field-month-relative+-1": "last month",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year": "Year",
	"field-era": "Era",
	"days-standAlone-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekdayOfMonth-narrow@localeAlias367": {
		"bundle": "",
		"target": "field-weekdayOfMonth-short"
	},
	"field-wed-narrow@localeAlias379": {
		"bundle": "",
		"target": "field-wed-short"
	},
	"field-weekdayOfMonth-narrow@localeAlias368": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"dateFormatItem-UMMMd": "U MMM d",
	"field-day-short-relative+-1": "yesterday",
	"dateFormatItem-GyMMM": "r(U) MMM",
	"days-standAlone-abbr@localeAlias313": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-standAlone-abbr@localeAlias314": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-weekdayOfMonth-short@localeAlias366": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"field-tue-short@localeAlias375": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-hour": "Hour",
	"field-wed-narrow@localeAlias380": {
		"bundle": "",
		"target": "field-wed"
	},
	"quarters@localeAlias319": {
		"bundle": "chinese",
		"target": "quarters"
	},
	"field-thu-short@localeAlias381": {
		"bundle": "",
		"target": "field-thu"
	},
	"field-day-narrow@localeAlias358": {
		"bundle": "",
		"target": "field-day-short"
	},
	"field-day-narrow@localeAlias359": {
		"bundle": "",
		"target": "field-day"
	},
	"field-minute-short@localeAlias396": {
		"bundle": "",
		"target": "field-minute"
	},
	"field-dayOfYear-narrow": "Day Of Year",
	"field-second-narrow-relative+0": "now",
	"field-quarter": "Quarter",
	"field-month-narrow-relative+0": "this month",
	"field-month-narrow-relative+1": "next month",
	"quarters@localeAlias320": {
		"bundle": "gregorian",
		"target": "quarters"
	},
	"dateFormatItem-yyyy": "r(U)",
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"field-day": "Day",
	"field-mon-relative+-1": "last Monday",
	"field-dayOfYear": "Day Of Year",
	"dateFormat-medium": "r MMM d",
	"dateTimeFormat-short": "{1} {0}",
	"dayPeriods-standAlone-narrow@localeAlias331": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-narrow@localeAlias332": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-sat-narrow@localeAlias388": {
		"bundle": "",
		"target": "field-sat-short"
	},
	"field-sat-narrow@localeAlias389": {
		"bundle": "",
		"target": "field-sat"
	},
	"dateFormatItem-GyMMMd": "r MMM d",
	"dateFormatItem-MEd": "MM-dd, E",
	"field-tue-short-relative+-1": "last Tuesday",
	"field-year-short": "Year",
	"field-month-short": "Month",
	"dateFormatItem-MMMEd": "MMM d, E",
	"days-format-short@localeAlias311": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"dateFormatItem-MMMd": "MMM d",
	"days-format-short@localeAlias312": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"dayPeriods-format-abbr-am": "AM",
	"field-zone-narrow@localeAlias403": {
		"bundle": "",
		"target": "field-zone-short"
	},
	"field-zone-narrow@localeAlias404": {
		"bundle": "",
		"target": "field-zone"
	},
	"field-sat-relative+0": "this Saturday",
	"dayPeriods-format-wide-pm": "PM",
	"field-sat-relative+1": "next Saturday",
	"dayPeriods-format-narrow@localeAlias328": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-second-narrow@localeAlias400": {
		"bundle": "",
		"target": "field-second-short"
	},
	"field-second-narrow@localeAlias401": {
		"bundle": "",
		"target": "field-second"
	},
	"field-year-short@localeAlias342": {
		"bundle": "",
		"target": "field-year"
	},
	"days-standAlone-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-era-short@localeAlias339": {
		"bundle": "",
		"target": "field-era"
	},
	"field-zone-short": "Zone",
	"field-week-short-relative+0": "this week",
	"field-week-short-relative+1": "next week",
	"dateFormatItem-yyyyMMMEd": "r(U) MMM d, E",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-fri-short-relative+-1": "last Friday",
	"field-month-narrow": "Month",
	"dayPeriods-format-narrow-am": "AM",
	"field-mon-short@localeAlias372": {
		"bundle": "",
		"target": "field-mon"
	},
	"field-month-narrow-relative+-1": "last month",
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-weekday-short": "Day of the Week",
	"field-day-narrow-relative+-1": "yesterday",
	"field-quarter-short": "Quarter",
	"days-format-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"months-standAlone-abbr@localeAlias304": {
		"bundle": "chinese",
		"target": "months-format-abbr"
	},
	"months-standAlone-abbr@localeAlias305": {
		"bundle": "chinese",
		"target": "months-format-wide"
	},
	"timeFormat@localeAlias336": {
		"bundle": "chinese",
		"target": "timeFormat"
	},
	"timeFormat@localeAlias337": {
		"bundle": "gregorian",
		"target": "timeFormat"
	},
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"field-quarter-narrow": "Quarter",
	"field-zone-short@localeAlias402": {
		"bundle": "",
		"target": "field-zone"
	},
	"field-mon-short-relative+0": "this Monday",
	"field-mon-short-relative+1": "next Monday",
	"days-standAlone-wide@localeAlias318": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-dayperiod-short": "Dayperiod",
	"dayPeriods-standAlone-narrow-am": "AM",
	"field-week-narrow-relative+-1": "last week",
	"field-thu-relative+-1": "last Thursday",
	"field-mon-short-relative+-1": "last Monday",
	"field-fri-narrow-relative+-1": "last Friday",
	"dayPeriods-standAlone-abbr@localeAlias330": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"quarters-standAlone-wide@localeAlias325": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"timeFormat-medium": "HH:mm:ss",
	"dateTime@localeAlias338": {
		"bundle": "chinese",
		"target": "dateTime"
	},
	"field-quarter-short-relative+0": "this quarter",
	"field-quarter-short-relative+1": "next quarter",
	"dateFormatItem-Ed": "d, E",
	"field-second-short@localeAlias399": {
		"bundle": "",
		"target": "field-second"
	},
	"field-wed-relative+-1": "last Wednesday",
	"field-weekOfMonth": "Week Of Month",
	"field-tue-narrow@localeAlias376": {
		"bundle": "",
		"target": "field-tue-short"
	},
	"field-tue-narrow@localeAlias377": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-weekdayOfMonth-narrow": "Weekday Of Month",
	"dayPeriods-standAlone-wide-am": "AM",
	"field-fri-relative+-1": "last Friday",
	"field-wed-short@localeAlias378": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-minute": "Minute",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-second-short-relative+0": "now",
	"quarters-format-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-day-short": "Day",
	"field-dayperiod": "Dayperiod",
	"field-hour-short": "Hour",
	"months-standAlone-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"field-month-relative+0": "this month",
	"field-second-narrow": "Second",
	"field-month-relative+1": "next month",
	"dateFormat-full": "r(U) MMMM d, EEEE",
	"dateFormatItem-yyyyMEd": "r-MM-dd, E",
	"field-era-narrow": "Era",
	"field-sat-short-relative+-1": "last Saturday",
	"field-week-short-relative+-1": "last week",
	"dateTimeFormat-long": "{1} {0}",
	"field-sun-relative+-1": "last Sunday",
	"field-wed-short-relative+-1": "last Wednesday",
	"dateFormatItem-yyyyQQQQ": "r(U) QQQQ",
	"field-weekdayOfMonth": "Weekday Of Month",
	"quarters-format-narrow@localeAlias322": {
		"bundle": "gregorian",
		"target": "quarters-standAlone-narrow"
	},
	"dateFormatItem-yyyyMd": "r-MM-dd",
	"field-quarter-narrow-relative+0": "this quarter",
	"field-year-narrow@localeAlias343": {
		"bundle": "",
		"target": "field-year-short"
	},
	"dateFormatItem-GyMMMEd": "r(U) MMM d, E",
	"field-quarter-narrow-relative+1": "next quarter",
	"field-year-narrow@localeAlias344": {
		"bundle": "",
		"target": "field-year"
	},
	"field-sat-short-relative+0": "this Saturday",
	"field-sat-short-relative+1": "next Saturday",
	"field-hour-narrow": "Hour",
	"days-standAlone-short@localeAlias315": {
		"bundle": "gregorian",
		"target": "days-format-short"
	},
	"field-year-narrow-relative+0": "this year",
	"days-standAlone-short@localeAlias316": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"field-year-narrow-relative+1": "next year",
	"field-hour-short@localeAlias393": {
		"bundle": "",
		"target": "field-hour"
	},
	"days-standAlone-short@localeAlias317": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-month-narrow@localeAlias349": {
		"bundle": "",
		"target": "field-month-short"
	},
	"dateFormatItem-Gy": "r U",
	"field-zone-narrow": "Zone",
	"dateFormatItem-yyyyM": "r-MM",
	"field-tue-relative+-1": "last Tuesday",
	"field-minute-short": "Minute",
	"field-month-narrow@localeAlias350": {
		"bundle": "",
		"target": "field-month"
	},
	"dateFormatItem-Hm": "HH:mm",
	"field-weekOfMonth-short@localeAlias354": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"field-week-relative+0": "this week",
	"field-week-relative+1": "next week",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"days-format-abbr@localeAlias309": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-sat-short@localeAlias387": {
		"bundle": "",
		"target": "field-sat"
	},
	"field-sat-narrow-relative+-1": "last Saturday",
	"months-standAlone-wide@localeAlias306": {
		"bundle": "chinese",
		"target": "months-format-wide"
	},
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-month-short-relative+-1": "last month",
	"dateFormatItem-MMMMd": "MMMM d",
	"field-week": "Week",
	"dateFormatItem-UMd": "U MM-d",
	"field-day-narrow": "Day",
	"field-hour-narrow-relative+0": "this hour"
}
//end v1.x content
,
	"cs": true,
	"fr": true,
	"id": true,
	"ja": true,
	"ko": true,
	"nb": true,
	"nl": true,
	"sv": true,
	"th": true,
	"zh": true,
	"zh-hant": true
});